@@ -12,5 +12,5 @@ from datetime import datetime
 def getstringdatetime():
 
     current_time = datetime.now()
-    strtime = current_time.strftime("%Y%h%d_%H-%M-%S")
+    strtime = current_time.strftime("%Y%h%d_%H%M%S")
     return strtime
